==> haskell-js-flot-0.8.3-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-flot
version:              0.8.3
visibility:           public
id:                   js-flot-0.8.3-GEeyYRHs5WhEVzTQ36tryA
key:                  js-flot-0.8.3-GEeyYRHs5WhEVzTQ36tryA
license:              MIT
copyright:            Neil Mitchell 2014
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-flot#readme
synopsis:             Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  7ccaff8daf375ef48ecb983c51b0d57a
exposed:              True
exposed-modules:      Language.Javascript.Flot
hidden-modules:       Paths_js_flot
import-dirs:          /usr/lib/ghc-8.8.3/site-local/js-flot-0.8.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-flot
hs-libraries:         HSjs-flot-0.8.3-GEeyYRHs5WhEVzTQ36tryA
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html:         /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-flot-0.8.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-flot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-flot
version:              0.8.3
visibility:           public
id:                   js-flot-0.8.3-BXlMi02db9F47UjjnQTlRL
key:                  js-flot-0.8.3-BXlMi02db9F47UjjnQTlRL
license:              MIT
copyright:            Neil Mitchell 2014
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-flot#readme
synopsis:             Obtain minified flot code
description:
    This package bundles the minified <http://www.flotcharts.org/ Flot> code
    (a jQuery plotting library) into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream flot version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  de6d732fbe2061226807dc1087fb6bc0
exposed:              True
exposed-modules:      Language.Javascript.Flot
hidden-modules:       Paths_js_flot
import-dirs:          /usr/lib/ghc-8.10.1/site-local/js-flot-0.8.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/js-flot-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-flot
hs-libraries:         HSjs-flot-0.8.3-BXlMi02db9F47UjjnQTlRL
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-js-flot/html/js-flot.haddock
haddock-html:         /usr/share/doc/haskell-js-flot/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
